--------------------------------------------------------------------------------
-- Copyright  2019								|
-- All Rights Reserved.								|
-- 										|
-- Permission to use, copy, modify, and distribute this software in any way	|
-- is not granted without expressed written agreement. This copyright applies	|
-- to the all code, data and artwork related to this project and all associated	|
-- projects published by the author.						|
--										|
-- For more information on copyright is available from sources on-line.		|
-- Use an actual factual one!							|
--------------------------------------------------------------------------------

---------------------------------------------------------------------------------------------
-- 	Enable Blizzard Raid Frames
-- 	Current character:
-- EnableAddOn("Blizzard_CompactRaidFrames") EnableAddOn("Blizzard_CUFProfiles")
-- 	All on current characters realm:
-- EnableAddOn("Blizzard_CompactRaidFrames", true) EnableAddOn("Blizzard_CUFProfiles", true)
---------------------------------------------------------------------------------------------

local AddonName, NS = ...

local L, UpdateSettings
local Container

local clip, find, sub = string.trim, string.find, string.sub

local DefaultSkinCount = 7
local FrameWidth, FrameHeight = 286, 300
local PrimaryTray, TraySettings
local CurrentButton = {}

local function ConfigureRaidFrames(parent)
	L = NS.TEXTS
	local DefaultSettings = NS:LoadSettingsRaidFrames()
	UpdateSettings = NS:GetOption("UpdateRaidSettings")
	if Container then
		Container:SetShown(not Container:IsShown())
		return Container
	end
	local Settings = NS:GetSettings("RaidFrames1")
	local CheckButtons = {}
	local Controls = {}
	local function CopySettings(character, charsettings)
		NS:CopySettings(character, charsettings, "RaidFrames1", Controls, CheckButtons)
		UpdateSettings()
	end

	local Settings = NS:GetSettings("RaidFrames1")
	
	Container = CreateFrame("Frame", "$parentRaidFrames", parent)
--	Container:Hide()
	Container:SetSize(FrameWidth, FrameHeight)

	Container.HighlightLabel = NS:CreateLabel(Container, "HighlightLabel", L.Highlight)
	Container.HighlightLabel:SetPoint("TOPLEFT", 40, -25)

	Container.HighlightLeader = NS.Lib:CreateLedCheckButton("HighlightLeader", Container, Settings.showrole, "HEALER", "Green")
	Container.HighlightLeader:SetSize(20, 20)
	NS:AddCheckLabel(Container.HighlightLeader, L.Leader, "RIGHT")
	Container.HighlightLeader:SetPoint("TOPLEFT", Container.HighlightLabel, "BOTTOMLEFT", -20, -5)
	function Container.HighlightLeader.PostUpdate(self)
		UpdateSettings()
	end
	CheckButtons[Container.HighlightLeader] = true

	Container.HighlightPlayer = NS.Lib:CreateLedCheckButton("HighlightPlayer", Container, Settings, "highlightplayer", "Green")
	Container.HighlightPlayer:SetSize(20, 20)
	NS:AddCheckLabel(Container.HighlightPlayer, L.Player, "RIGHT")
	Container.HighlightPlayer:SetPoint("TOPLEFT", Container.HighlightLeader, "BOTTOMLEFT", 0, -5)
	function Container.HighlightPlayer.PostUpdate(self)
		UpdateSettings()
	end
	CheckButtons[Container.HighlightPlayer] = true -- true = use base settings, not branch

	Container.RolesLabel = NS:CreateLabel(Container, "RolesLabel", L.RoleIcons)
	Container.RolesLabel:SetPoint("TOPLEFT", Container.HighlightPlayer, "BOTTOMRIGHT", 0, -31)

	Container.RoleTank = NS.Lib:CreateLedCheckButton("RoleTank", Container, Settings.showrole, "TANK", "Green")
	Container.RoleTank:SetSize(20, 20)
	NS:AddCheckLabel(Container.RoleTank, L.Tank, "RIGHT")
	Container.RoleTank:SetPoint("TOPLEFT", Container.RolesLabel, "BOTTOMLEFT", -20, -5)
	function Container.RoleTank.PostUpdate(self)
		UpdateSettings()
	end
	CheckButtons[Container.RoleTank] = "showrole"

	Container.RoleHealer = NS.Lib:CreateLedCheckButton("RoleHealer", Container, Settings.showrole, "HEALER", "Green")
	Container.RoleHealer:SetSize(20, 20)
	NS:AddCheckLabel(Container.RoleHealer, L.Healer, "RIGHT")
	Container.RoleHealer:SetPoint("TOPLEFT", Container.RoleTank, "BOTTOMLEFT", 0, -5)
	function Container.RoleHealer.PostUpdate(self)
		UpdateSettings()
	end
	CheckButtons[Container.RoleHealer] = "showrole"

	Container.RoleDamage = NS.Lib:CreateLedCheckButton("RoleDamage", Container, Settings.showrole, "DAMAGE", "Green")
	Container.RoleDamage:SetSize(20, 20)
	NS:AddCheckLabel(Container.RoleDamage, L.Damage, "RIGHT")
	Container.RoleDamage:SetPoint("TOPLEFT", Container.RoleHealer, "BOTTOMLEFT", 0, -5)
	function Container.RoleDamage.PostUpdate(self)
		UpdateSettings()
	end
	CheckButtons[Container.RoleDamage] = "showrole"


	Container.AlphasLabel = NS:CreateLabel(Container, "AlphasLabel", L.Alpha)
	Container.AlphasLabel:SetPoint("TOPLEFT", Container.RoleDamage, "BOTTOMRIGHT", 0, -6)

	Container.NormalAlpha = NS.Lib:CreateSlider("NormalAlpha", Container, Settings.backgroundcolor, "a", 20, true, 100, true, 1, 90, 20, nil, nil, 100)
	Container.NormalAlpha:SetLabel(L.Normal, "TOP", 0, -2)
	Container.NormalAlpha:SetPoint("TOP", Container.AlphasLabel, "BOTTOM", 0, -18)
	function Container.NormalAlpha:PostUpdate()
		UpdateSettings()
	end
	Controls[Container.NormalAlpha] = "backgroundcolor"

	Container.OORangeAlpha = NS.Lib:CreateSlider("OORangeAlpha", Container, Settings, "oorangealpha", 20, true, 100, true, 1, 90, 20, nil, nil, 100)
	Container.OORangeAlpha:SetLabel(L.OORange, "TOP", 0, -2)
	Container.OORangeAlpha:SetPoint("TOP", Container.NormalAlpha, "BOTTOM", 0, -20)
	function Container.OORangeAlpha:PostUpdate()
		UpdateSettings()
	end
	Controls[Container.OORangeAlpha] = "backgroundcolor"

	Container.ColorsLabel = NS:CreateLabel(Container, "ColorsLabel", L.Colors, 10)
	Container.ColorsLabel:SetPoint("TOPRIGHT", -50, -25)

	Container.BackgroundColor = NS.Lib:CreateLEDColorPickerButton("BackgroundColor", Container, Settings, "backgroundcolor")
	Container.BackgroundColor:SetSize(18, 18)
	Container.BackgroundColor:SetPoint("TOPLEFT", Container.ColorsLabel, "BOTTOMLEFT", -20, -5)
	Container.BackgroundColor.DefaultColor = DefaultSettings.backgroundcolor
	NS:AddCheckLabel(Container.BackgroundColor, L.Background, "RIGHT")
	Container.BackgroundColor:SetToolTip(L.ColorPickerTip)
	Container.BackgroundColor.PostUpdate = function()
		UpdateSettings()
	end
	Controls[Container.BackgroundColor] = true

	Container.ClassNames = NS.Lib:CreateLedCheckButton("ClassNames", Container, Settings, "classnamecolors", "Green")
	Container.ClassNames:SetSize(20, 20)
	NS:AddCheckLabel(Container.ClassNames, L.GetText(L.BackgroundColors, L.Names, L.ByClass), "RIGHT")
	Container.ClassNames:SetPoint("TOPLEFT", Container.BackgroundColor, "BOTTOMLEFT", 0, -8)
	function Container.ClassNames.PostUpdate(self)
		Container.NameColor:SetEnabled(not self:GetChecked())
		UpdateSettings()
	end
	CheckButtons[Container.ClassNames] = true

	Container.NameColor = NS.Lib:CreateLEDColorPickerButton("NameColor", Container, Settings, "namecolor")
	Container.NameColor:SetSize(18, 18)
	Container.NameColor:SetPoint("TOPLEFT", Container.ClassNames, "BOTTOMRIGHT", 0, -5)
	Container.NameColor.DefaultColor = DefaultSettings.namecolor
	NS:AddCheckLabel(Container.NameColor, L.Fixed, "RIGHT")
	Container.NameColor:SetToolTip(L.ColorPickerTip)
	Container.NameColor.PostUpdate = function()
		UpdateSettings()
	end
	Container.NameColor:SetEnabled(not Container.ClassNames:GetChecked())
	Controls[Container.NameColor] = true

	Container.HealthLabel = NS:CreateLabel(Container, "HealthLabel", L.Health)
	Container.HealthLabel:SetPoint("TOPLEFT", Container.NameColor, "BOTTOMLEFT", -2, -8)

	Container.FullHealthColor = NS.Lib:CreateLEDColorPickerButton("FullHealthColor", Container, Settings.healthcolor, "default")
	Container.FullHealthColor:SetSize(18, 18)
	Container.FullHealthColor:SetPoint("TOPLEFT", Container.HealthLabel, "BOTTOMLEFT", -20, -5)
	Container.FullHealthColor.DefaultColor = DefaultSettings.healthcolor.default
	NS:AddCheckLabel(Container.FullHealthColor, L.Full, "RIGHT")
	Container.FullHealthColor:SetToolTip(L.ColorPickerTip)
	Container.FullHealthColor.PostUpdate = function()
		UpdateSettings()
	end
	Controls[Container.FullHealthColor] = "healthcolor"

	Container.LowHealthColor = NS.Lib:CreateLEDColorPickerButton("LowHealthColor", Container, Settings.healthcolor, "low")
	Container.LowHealthColor:SetSize(18, 18)
	Container.LowHealthColor:SetPoint("TOPLEFT", Container.FullHealthColor, "BOTTOMLEFT", 0, -5)
	Container.LowHealthColor.DefaultColor = DefaultSettings.healthcolor.low
	NS:AddCheckLabel(Container.LowHealthColor, L.Low, "RIGHT")
	Container.LowHealthColor:SetToolTip(L.ColorPickerTip)
--	Container.LowHealthColor.PostUpdate = function()
--		UpdateSettings()
--	end
	Controls[Container.LowHealthColor] = "healthcolor"

	Container.CriticalHealthColor = NS.Lib:CreateLEDColorPickerButton("CriticalHealthColor", Container, Settings.healthcolor, "critical")
	Container.CriticalHealthColor:SetSize(18, 18)
	Container.CriticalHealthColor:SetPoint("TOPLEFT", Container.LowHealthColor, "BOTTOMLEFT", 0, -5)
	Container.CriticalHealthColor.DefaultColor = DefaultSettings.healthcolor.critical
	NS:AddCheckLabel(Container.CriticalHealthColor, L.Critical, "RIGHT")
	Container.CriticalHealthColor:SetToolTip(L.ColorPickerTip)
--	Container.CriticalHealthColor.PostUpdate = function()
--		UpdateSettings()
--	end
	Controls[Container.CriticalHealthColor] = "healthcolor"

	Container.ThresholdslowLabel = NS:CreateLabel(Container, "ThresholdslowLabel", L.Thresholds)
	Container.ThresholdslowLabel:SetPoint("TOPLEFT", Container.CriticalHealthColor, "BOTTOMRIGHT", 0, -10)

	Container.ThresholdLow = NS.Lib:CreateSlider("ThresholdLow", Container, Settings.healthcolor, "thresholdlow", 56, true, 85, true, 1, 90, 20, nil, nil, 100)
	Container.ThresholdLow:SetLabel(L.Low.." @%", "TOP", 0, -2)
	Container.ThresholdLow:SetPoint("TOP", Container.ThresholdslowLabel, "BOTTOM", 0, -20)
--	function Container.ThresholdLow:PostUpdate()
--		UpdateSettings()
--	end
	Controls[Container.ThresholdLow] = "healthcolor"

	Container.ThresholdCritical = NS.Lib:CreateSlider("ThresholdCritical", Container, Settings.healthcolor, "thresholdcritical", 20, true, 55, true, 1, 90, 20, nil, nil, 100)
	Container.ThresholdCritical:SetLabel(L.Critical.." @%", "TOP", 0, -2)
	Container.ThresholdCritical:SetPoint("TOP", Container.ThresholdLow, "BOTTOM", 0, -20)
--	function Container.ThresholdCritical:PostUpdate()
--		UpdateSettings()
--	end
	Controls[Container.ThresholdCritical] = "healthcolor"

	Container:HookScript("OnShow", function(self)
		NS:GetOption("RaidFrameConfigMode")(true)
		NS:PlaceCopyButton(CopySettings, 10, 0, "TOPRIGHT", Container, "TOPRIGHT", -20, -8)
	end)
	Container:HookScript("OnHide", function(self)
		NS:GetOption("RaidFrameConfigMode")(NS:GetSettings("RaidFrames1").showsolo)
	end)
	Container:GetScript("OnShow")(Container)
	return Container
end

local function CheckEnabled(self)
	local Settings = NS:GetSettings("Addons").RaidFrames1
	self:SetEnabled(not Settings.inactive)
end
NS:RegisterModule("RaidFrames", "RaidFrames", "RaidFrames", ConfigureRaidFrames, nil, nil, nil, nil, CheckEnabled)
